# 3aransia

The Latin/Digit Moroccan Language Framework


[![Open Source Love](https://badges.frapsoft.com/os/v1/open-source.svg?v=102)](https://github.com/ellerbrock/open-source-badge/)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
![GitHub last commit](https://img.shields.io/github/last-commit/google/skia.svg)

## Prerequisites

- [`Python 3`](https://www.python.org/downloads/)
  
## Installation

```pip install aaransia```

## Usage

```python
from aaransia import transliterate_moroccan, transliterate_moroccan_arabic

transliterate_moroccan('ktb bl3rbia hnaya')
transliterate_moroccan_arabic('كتب بلعربيا هنايا')
```

```
>>> كتب بلعربيا هنايا
>>> ktb bl3rbia hnaya
```

## Other related projects

- [3aransia.api](https://github.com/3aransia/3aransia.api) The api of 3aransia
- [3aransia.web](https://github.com/3aransia/3aransia.web) The web app of 3aransia
- [3aransia.js](https://github.com/3aransia/3aransia.js) 3aransia in JS
- [3aransia.datasets](https://github.com/3aransia/3aransia.datatsets) The datasets of 3aransia
